import express from 'express';
import * as http from 'http';
import * as dotenv from 'dotenv';
// Router imports
import {partyPlanerRouter} from './src/models/partyplaner/PartyPlaner.router';
import {highlightMarkerRouter} from './src/models/twitch-highlight-marker/HighlightMarker.router';
import {dhbwServiceRouter} from './src/models/dhbw-service/DHBWService.router';

dotenv.config();

if (!process.env.PORT) {
    console.log('No port');
    process.exit(1);
}

const port: number = parseInt(process.env.PORT, 10);

const app: express.Application = express();
const server: http.Server = http.createServer(app);

// here we are adding middleware to parse all incoming requests as JSON
app.use(express.json());

// Add routers
app.use('/dhbw-service', dhbwServiceRouter);
app.use('/twitch-highlight-marker', highlightMarkerRouter);
app.use('/partyplaner', partyPlanerRouter);

// this is a simple route to make sure everything is working properly
app.get('/', (req: express.Request, res: express.Response) => {
    res.status(200).send('Welcome to the Pluto Development REST API V2!');
});

server.listen(port, () => {
    console.log('Server listening on Port ' + port);
});
